#ifndef _XmdMap_h
#define _XmdMap_h

#include <X11/Intrinsic.h>

/* XmdMapKey is used to key XmdMap. */
typedef long unsigned int XmdMapKey;

/* XmdMap is a hash map that is keyed by an integer and can store any type of
   element. */
typedef struct _XmdMap XmdMap;

/* XmdMapIterator is a function that can iterate over a map. */
typedef Bool (*XmdMapIterator) (
	XmdMap *map,
	XmdMapKey key, void *value,
	void *clientData);

/* XmdMapNew creates a new map.*/
XmdMap *XmdMapNew ();

/* XmdMapGet retrieves a value from a map. */
void *XmdMapGet (XmdMap *map, XmdMapKey key);

/* XmdMapSet sets a value in a map. The previous value associated with the key,
   if it exists, is overwritten by the new value. If the value is set to NULL,
   the key/value combination is deleted from the map. This function returns
   the previous value associated with the key so it can be free'd if necessary.
   */
void *XmdMapSet (XmdMap *map, XmdMapKey key, void *value);

/* XmdMapIterate calls iterator for each key/value pair in a map. */
void XmdMapIterate (XmdMap *map, XmdMapIterator iterator, void *clientData);

/* XmdMapLength returns the number of key/value entries stored in a map. */
Cardinal XmdMapLength (XmdMap *map);

/* XmdMapFree frees the map and any data associated with it. Note that this will
   not free any of the map's values. */
void XmdMapFree (XmdMap *map);

#endif
